/// <reference types="jquery" />
/// <reference types="jquery" />
import { BasePubSubService, EventSubscription } from '@slickgrid-universal/event-pub-sub';
import { ExtensionUtility } from '../extensions/extensionUtility';
import { Column, DraggableGrouping, DraggableGroupingOption, GridOption, GroupingGetterFunction, HtmlElementPosition, SlickDataView, SlickEvent, SlickEventHandler, SlickGrid } from '../interfaces/index';
import { BindingEventService } from '../services/bindingEvent.service';
import { SharedService } from '../services/shared.service';
export interface JQueryUiDraggableOption {
    draggable: any;
    helper: any;
    originalPosition: {
        left: number;
        top: number;
    };
    placeholder?: string;
    position?: HtmlElementPosition;
    sender?: any;
    offset?: HtmlElementPosition;
}
export interface JQueryUiSortableOptions {
    distance?: number;
    cursor?: string;
    tolerance?: string;
    helper?: string;
    placeholder?: string;
    forcePlaceholderSize?: boolean;
    appendTo?: string;
    start?: (e: Event, ui: JQueryUiDraggableOption) => void;
    beforeStop?: (e: Event, ui: JQueryUiDraggableOption) => void;
    stop?: (e: any) => void;
}
/**
 *
 * Draggable Grouping contributed by:  Muthukumar Selconstasu
 *  muthukumar{dot}se{at}gmail{dot}com
 *  github.com/muthukumarse/Slickgrid
 *
 * NOTES:
 *     This plugin provides the Draggable Grouping feature
 *
 * A plugin to add drop-down menus to column headers.
 * To specify a custom button in a column header, extend the column definition like so:
 *   this.columnDefinitions = [{
 *     id: 'cost', name: 'Cost', field: 'cost',
 *     grouping: {
 *       getter: 'cost',
 *       formatter: (g) => `Cost: ${g.value} <span style="color:green">(${g.count} items)</span>`,
 *       aggregators: [new Aggregators.Sum('cost')],
 *       aggregateCollapsed: true,
 *       collapsed: true
 *     }
 *   }];
 */
export declare class SlickDraggableGrouping {
    protected readonly extensionUtility: ExtensionUtility;
    protected readonly pubSubService: BasePubSubService;
    protected readonly sharedService: SharedService;
    protected _addonOptions: DraggableGroupingOption;
    protected _bindEventService: BindingEventService;
    protected _droppableInstance: any;
    protected _dropboxElm: HTMLDivElement;
    protected _dropboxPlaceholderElm: HTMLDivElement;
    protected _eventHandler: SlickEventHandler;
    protected _grid?: SlickGrid;
    protected _gridColumns: Column[];
    protected _gridUid: string;
    protected _groupToggler?: HTMLDivElement;
    protected _sortableInstance: any;
    protected _subscriptions: EventSubscription[];
    protected _defaults: DraggableGroupingOption;
    columnsGroupBy: Column[];
    onGroupChanged: SlickEvent;
    pluginName: 'DraggableGrouping';
    /** Constructor of the SlickGrid 3rd party plugin, it can optionally receive options */
    constructor(extensionUtility: ExtensionUtility, pubSubService: BasePubSubService, sharedService: SharedService);
    get addonOptions(): DraggableGroupingOption;
    /** Getter of SlickGrid DataView object */
    get dataView(): SlickDataView;
    get dropboxElement(): HTMLDivElement;
    get droppableInstance(): any;
    get sortableInstance(): any;
    get eventHandler(): SlickEventHandler;
    get grid(): SlickGrid;
    get gridOptions(): GridOption;
    /** Getter for the grid uid */
    get gridUid(): string;
    get gridUidSelector(): string;
    /** Initialize plugin. */
    init(grid: SlickGrid, groupingOptions?: DraggableGrouping): this;
    /** Dispose the plugin. */
    dispose(): void;
    clearDroppedGroups(): void;
    setColumns(cols: Column[]): void;
    setDroppedGroups(groupingInfo: Array<string | GroupingGetterFunction> | string): void;
    setupColumnReorder(grid: SlickGrid, $headers: any, _headerColumnWidthDiff: any, setColumns: (columns: Column[]) => void, setupColumnResize: () => void, columns: Column[], getColumnIndex: (column: Column) => number, uid: string, trigger: (slickEvent: SlickEvent, data?: any) => void): any;
    protected addColumnGroupBy(column: Column): void;
    protected addGroupByRemoveClickHandler(id: string | number, _container: HTMLDivElement, headerColumn: JQuery<HTMLDivElement>, entry: any): void;
    protected handleGroupByDrop(container: HTMLDivElement, headerColumn: JQuery<HTMLDivElement>): void;
    protected removeFromArray(arrayToModify: any[], itemToRemove: any): any[];
    protected removeGroupBy(id: string | number, _hdrColumn: JQuery<HTMLDivElement>, entry: any): void;
    protected setupColumnDropbox(): void;
    protected toggleGroupToggler(targetElm: Element | null, collapsing?: boolean, shouldExecuteDataViewCommand?: boolean): void;
    protected updateGroupBy(originator: string): void;
}
