import { FieldType } from '../enums/fieldType.enum';
import { mapMomentDateFormatWithFieldType } from '../services/utilities';
import * as moment_ from 'moment-mini';
const moment = moment_['default'] || moment_; // patch to fix rollup "moment has no default export" issue, document here https://github.com/rollup/rollup/issues/670
export function compareDates(value1, value2, sortDirection, sortColumn, gridOptions, format, strict) {
    var _a, _b;
    let diff = 0;
    const checkForUndefinedValues = (_b = (_a = sortColumn === null || sortColumn === void 0 ? void 0 : sortColumn.valueCouldBeUndefined) !== null && _a !== void 0 ? _a : gridOptions === null || gridOptions === void 0 ? void 0 : gridOptions.cellValueCouldBeUndefined) !== null && _b !== void 0 ? _b : false;
    const date1 = moment(value1, format, strict);
    const date2 = moment(value2, format, strict);
    if (value1 === null || value1 === '' || (checkForUndefinedValues && value1 === undefined) || !date1.isValid()) {
        diff = -1;
    }
    else if (value2 === null || value2 === '' || (checkForUndefinedValues && value2 === undefined) || !date2.isValid()) {
        diff = 1;
    }
    else {
        diff = date1.valueOf() < date2.valueOf() ? -1 : 1;
    }
    return sortDirection * diff;
}
/** From a FieldType, return the associated Date SortComparer */
export function getAssociatedDateSortComparer(fieldType) {
    const FORMAT = (fieldType === FieldType.date) ? moment.ISO_8601 : mapMomentDateFormatWithFieldType(fieldType);
    return ((value1, value2, sortDirection, sortColumn, gridOptions) => {
        if (FORMAT === moment.ISO_8601) {
            return compareDates(value1, value2, sortDirection, sortColumn, gridOptions, FORMAT, false);
        }
        return compareDates(value1, value2, sortDirection, sortColumn, gridOptions, FORMAT, true);
    });
}
//# sourceMappingURL=dateUtilities.js.map